import pyaudio
def check_mic():
    p = pyaudio.PyAudio()
    for i in range(p.get_device_count()):
        dev = p.get_device_info_by_index(i)
        if dev['maxInputChannels'] == 0:
            continue
        print((i,dev['name'],dev['maxInputChannels']))


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: speech2text.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='speech2text.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11speech2text.proto\"!\n\x05\x41udio\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\n\n\x02sr\x18\x03 \x01(\x05\"\x1a\n\nTranscript\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t2]\n\x03\x41SR\x12-\n\x10TranscribeStream\x12\x06.Audio\x1a\x0b.Transcript\"\x00(\x01\x30\x01\x12\'\n\nTestStream\x12\x06.Audio\x1a\x0b.Transcript\"\x00(\x01\x30\x01\x62\x06proto3'
)




_AUDIO = _descriptor.Descriptor(
  name='Audio',
  full_name='Audio',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Audio.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sr', full_name='Audio.sr', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21,
  serialized_end=54,
)


_TRANSCRIPT = _descriptor.Descriptor(
  name='Transcript',
  full_name='Transcript',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='Transcript.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=56,
  serialized_end=82,
)

DESCRIPTOR.message_types_by_name['Audio'] = _AUDIO
DESCRIPTOR.message_types_by_name['Transcript'] = _TRANSCRIPT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Audio = _reflection.GeneratedProtocolMessageType('Audio', (_message.Message,), {
  'DESCRIPTOR' : _AUDIO,
  '__module__' : 'speech2text_pb2'
  # @@protoc_insertion_point(class_scope:Audio)
  })
_sym_db.RegisterMessage(Audio)

Transcript = _reflection.GeneratedProtocolMessageType('Transcript', (_message.Message,), {
  'DESCRIPTOR' : _TRANSCRIPT,
  '__module__' : 'speech2text_pb2'
  # @@protoc_insertion_point(class_scope:Transcript)
  })
_sym_db.RegisterMessage(Transcript)



_ASR = _descriptor.ServiceDescriptor(
  name='ASR',
  full_name='ASR',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=84,
  serialized_end=177,
  methods=[
  _descriptor.MethodDescriptor(
    name='TranscribeStream',
    full_name='ASR.TranscribeStream',
    index=0,
    containing_service=None,
    input_type=_AUDIO,
    output_type=_TRANSCRIPT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TestStream',
    full_name='ASR.TestStream',
    index=1,
    containing_service=None,
    input_type=_AUDIO,
    output_type=_TRANSCRIPT,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ASR)

DESCRIPTOR.services_by_name['ASR'] = _ASR

# @@protoc_insertion_point(module_scope)



from datetime import datetime
def stream_output(transcript, status):
    return {
        'timestamp': datetime.now().strftime("%d/%m/%Y %H:%M:%S"),
        'result': {'transcript': transcript},
        'status': status
    }


from setuptools import setup, find_packages

VERSION = '0.1.11' 
DESCRIPTION = 'Botnoi speech to text client'
LONG_DESCRIPTION = ''

# Setting up
setup(
       # the name must match the folder name 'verysimplemodule'
        name="bnasr", 
        version=VERSION,
        author="Peerapon Wechsuwanmanee",
        author_email="peerapon.w@gmail.com",
        description=DESCRIPTION,
        long_description=LONG_DESCRIPTION,
        packages=find_packages(),
        install_requires=[
            'grpcio',
            'protobuf',
            ], 
        
        keywords=['python', 'speech recognition', 'speech to text', 'botnoi'],
        classifiers= [
            "Programming Language :: Python :: 3",
            "Operating System :: MacOS :: MacOS X",
            "Operating System :: Microsoft :: Windows",
        ]
)